@@ -33,6 +33,9 @@
 ##' (2002b) (Eqs. 7a to 11), assuming that the recombination fraction is the
 ##' same in both parents. Hidden Markov chain codes adapted from Broman et al.
 ##' (2008) were used.
+##' 
+##' @importFrom methods is
+##' @importFrom utils setTxtProgressBar txtProgressBar tail head
 ##'
 ##' @param input.seq an object of class \code{sequence}.
 ##' @param n.best the number of best orders to store in object (defaults to
@@ -82,8 +85,8 @@
 ##'
 ##' \dontrun{
 ##'   #outcrossing example
-##'   data(example_out)
-##'   twopt <- rf_2pts(example_out)
+##'   data(onemap_example_out)
+##'   twopt <- rf_2pts(onemap_example_out)
 ##'   markers <- make_seq(twopt,c(12,14,15,26,28))
 ##'   (markers.comp <- compare(markers))
 ##'   (markers.comp <- compare(markers,verbose=TRUE))
@@ -97,7 +100,7 @@
 ##'
 ##' }
 ##'
-##'
+##'@export
 
 compare<- function(input.seq,n.best=50,tol=10E-4,verbose=FALSE) {
     if(is(get(input.seq$data.name), "outcross"))
@@ -115,7 +118,7 @@ compare_outcross<- function(input.seq,n.best=50,tol=10E-4,verbose=FALSE)
         stop(sQuote(deparse(substitute(input.seq)))," is not an object of class 'sequence'")
     if(length(input.seq$seq.num) > 5)
         cat("WARNING: this operation may take a VERY long time\n")
-    flush.console()
+    utils::flush.console()
     if(length(input.seq$seq.num) > 10) {
         cat("\nIt is not wise trying to use 'compare' with more than 10 markers \n")
         ANSWER <- readline("Are you sure you want to proceed? [y or n]\n")
@@ -144,7 +147,7 @@ compare_outcross<- function(input.seq,n.best=50,tol=10E-4,verbose=FALSE)
             for(i in 1:nrow(all.ord)){
                 ## print output for each order
                 cat("Order", i, ":", all.ord[i,], "\n")
-                flush.console()
+                utils::flush.console()
                 ## get initial values for the HMM
                 all.match <- match(all.ord[i,],input.seq$seq.num)
                 for(j in 1:(length(input.seq$seq.num)-1)){
@@ -205,7 +208,7 @@ compare_outcross<- function(input.seq,n.best=50,tol=10E-4,verbose=FALSE)
             ##      cat(rep("\b",nchar(nc)+1),sep="")
             ##      nc<-round(i*100/nrow(all.ord))
             ##      cat(nc,"%", sep="")
-            ##      flush.console()
+            ##      utils::flush.console()
             ##    }
             ## get initial values for the HMM
             all.match <- match(all.ord[i,],input.seq$seq.num)
@@ -277,7 +280,7 @@ compare_inbred<- function(input.seq,n.best=50,tol=10E-4,verbose=FALSE) {
         stop(sQuote(deparse(substitute(input.seq)))," is not an object of class 'sequence'")
     if(length(input.seq$seq.num) > 5)
         cat("WARNING: this operation may take a VERY long time\n")
-    flush.console()
+    utils::flush.console()
     if(length(input.seq$seq.num) > 10) {
         cat("\nIt is not wisely trying to use 'compare' with more than 10 markers \n")
         ANSWER <- readline("Are you sure you want to proceed? [y or n]\n")
@@ -307,7 +310,7 @@ compare_inbred<- function(input.seq,n.best=50,tol=10E-4,verbose=FALSE) {
         {
             ## print output for each order
             if (verbose) cat("Order", i, ":", all.ord[i,], "\n")
-            flush.console()
+            utils::flush.console()
             seq.temp<-make_seq(get(input.seq$twopt), arg=all.ord[i,])
             seq.temp$twopt<-input.seq$twopt
             rf.temp<-get_vec_rf_in(seq.temp, acum=FALSE)
@@ -344,6 +347,8 @@ compare_inbred<- function(input.seq,n.best=50,tol=10E-4,verbose=FALSE) {
 }
 
 ## print method for object class 'compare'
+##'@export
+##'@method print compare
 print.compare <- function(x,...) {
         FLAG<-0
         if(!is(get(x$data.name, pos=1), "outcross")) FLAG<-1
