@@ -12,7 +12,7 @@
 ## copyright (c) 2015 Antonio Augusto Franco Garcia                    ##
 ##                                                                     ##
 ## First version: 2015/04/18                                           ##
-## Last update: 2017/08/02                                             ##
+## Last update: 2017/11/08                                             ##
 ## License: GNU General Public License version 3 or later              ##
 ##                                                                     ##
 #######################################################################
@@ -28,6 +28,8 @@ globalVariables(c("Marker", "p.value"))
 ##' First, the function selects the correct segregation pattern, then it
 ##' defines the H0 hypothesis, and then tests it, together with percentage of
 ##' missing data.
+##' 
+##' @importFrom stats chisq.test cor.test dist na.omit qchisq rf setNames
 ##'
 ##' @param x an object of class \code{onemap}, with data and additional information.
 ##' @param marker the marker which will be tested for its segregation.
@@ -36,13 +38,19 @@ globalVariables(c("Marker", "p.value"))
 ##' the associated p-values, and the \% of individuals genotyped.
 ##'
 ##' ##'@examples
-##' data(mapmaker_example_bc) # Loads a fake backcross dataset installed with onemap
-##' test_segregation_of_a_marker(mapmaker_example_bc,1)
+##' data(onemap_example_bc) # Loads a fake backcross dataset installed with onemap
+##' test_segregation_of_a_marker(onemap_example_bc,1)
 ##'
-##' data(example_out) # Loads a fake outcross dataset installed with onemap
-##' test_segregation_of_a_marker(example_out,1)
+##' data(onemap_example_out) # Loads a fake outcross dataset installed with onemap
+##' test_segregation_of_a_marker(onemap_example_out,1)
+##' @export
 test_segregation_of_a_marker <- function(x, marker) {
-    options(warn=-1) #Supress warnings from function chisq.test - when cell have < 5 elements
+  options(warn=-1) #Supress warnings from function chisq.test - when cell have < 5 elements
+  # Break if marker has any genotype information
+  if(all(x$geno[,marker] ==0)) {
+    warning(cat("Marker", marker, "do not have genotype information for any sample. We suggest to remove it from the dataset\n"))
+    return(list(Hypothesis=NA, qui.quad=NA, p.val=NA, perc.genot=NA))
+  } else {
     ## Segregation pattern for each marker type
     p.a <- rep(1/4, 4); p.b <- c(1/4, 1/2, 1/4); p.c <- c(3/4, 1/4); p.d <- rep(1/2, 2)
     ## Counting each category, removing missing data (coded as 0)
@@ -51,68 +59,75 @@ test_segregation_of_a_marker <- function(x, marker) {
     ## grepl() allows finding the marker type (it has the letter in the argument)
     ## Some markers may not have data for some classes, so fill them with 0
     if (grepl("A.H.B",x$segr.type[marker])) {
-            if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
-            if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
-            if (is.element(1,x$geno[,marker])) c3 <- count[names(count)==3] else c3 <- 0
-            qui <- chisq.test(c(c1,c2,c3), p=p.b, correct = FALSE)
-            H0 <- "1:2:1"
+      if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
+      if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
+      if (is.element(3,x$geno[,marker])) c3 <- count[names(count)==3] else c3 <- 0
+      qui <- chisq.test(c(c1,c2,c3), p=p.b, correct = FALSE)
+      H0 <- "1:2:1"
     }
     else if (grepl("C.A",x$segr.type[marker])) {
-          if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
-          if (is.element(5,x$geno[,marker])) c2 <- count[names(count)==5] else c2 <- 0
-          qui <- chisq.test(as.vector(c(c1,c2)), p=rev(p.c), correct = FALSE)
-          H0 <- "3:1"
-      }
+      if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
+      if (is.element(5,x$geno[,marker])) c2 <- count[names(count)==5] else c2 <- 0
+      qui <- chisq.test(as.vector(c(c1,c2)), p=rev(p.c), correct = FALSE)
+      H0 <- "3:1"
+    }
     else if (grepl("D.B",x$segr.type[marker])) {
-          if (is.element(3,x$geno[,marker])) c1 <- count[names(count)==3] else c1 <- 0
-          if (is.element(4,x$geno[,marker])) c2 <- count[names(count)==4] else c2 <- 0
-          qui <- chisq.test(as.vector(c(c1,c2)), p=rev(p.c), correct = FALSE)
-          H0 <- "3:1"
+      if (is.element(3,x$geno[,marker])) c1 <- count[names(count)==3] else c1 <- 0
+      if (is.element(4,x$geno[,marker])) c2 <- count[names(count)==4] else c2 <- 0
+      qui <- chisq.test(as.vector(c(c1,c2)), p=rev(p.c), correct = FALSE)
+      H0 <- "3:1"
     }
-    else if (grepl("A.H",x$segr.type[marker]) | grepl("A.B",x$segr.type[marker])) {
-          if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
-          if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
-          qui <- chisq.test(as.vector(c(c1,c2)), p=p.d, correct = FALSE)
-          H0 <- "1:1"
+    else if (grepl("A.H",x$segr.type[marker])) {
+      if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
+      if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
+      qui <- chisq.test(as.vector(c(c1,c2)), p=p.d, correct = FALSE)
+      H0 <- "1:1"
     }
-    else if (grepl("A",x$segr.type[marker])) {
-          if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
-          if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
-          if (is.element(3,x$geno[,marker])) c3 <- count[names(count)==3] else c3 <- 0
-          if (is.element(4,x$geno[,marker])) c4 <- count[names(count)==4] else c4 <- 0
-          qui <- chisq.test(as.vector(c(c1,c2,c3,c4)), p=p.a, correct = FALSE)
-          H0 <- "1:1:1:1"
+    else if (grepl("A.B",x$segr.type[marker])) {
+      if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
+      if (is.element(3,x$geno[,marker])) c2 <- count[names(count)==3] else c2 <- 0
+      qui <- chisq.test(as.vector(c(c1,c2)), p=p.d, correct = FALSE)
+      H0 <- "1:1"
     }
-    else if (grepl("B",x$segr.type[marker])) {
-            if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
-            if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
-            if (is.element(3,x$geno[,marker])) c3 <- count[names(count)==3] else c3 <- 0
-            qui <- chisq.test(as.vector(c(c1,c2,c3)), p=p.b, correct = FALSE)
-            H0 <- "1:2:1"
+    else if (grepl("A",x$segr.type[marker]) & class(x)[2]=="outcross") {
+      if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
+      if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
+      if (is.element(3,x$geno[,marker])) c3 <- count[names(count)==3] else c3 <- 0
+      if (is.element(4,x$geno[,marker])) c4 <- count[names(count)==4] else c4 <- 0
+      qui <- chisq.test(as.vector(c(c1,c2,c3,c4)), p=p.a, correct = FALSE)
+      H0 <- "1:1:1:1"
     }
-    else if (grepl("C",x$segr.type[marker])) {
-          if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
-          if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
-          qui <- chisq.test(as.vector(c(c1,c2)), p=p.c, correct = FALSE)
-          H0 <- "3:1"
+    else if (grepl("B",x$segr.type[marker]) & class(x)[2]=="outcross") {
+      if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
+      if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
+      if (is.element(3,x$geno[,marker])) c3 <- count[names(count)==3] else c3 <- 0
+      qui <- chisq.test(as.vector(c(c1,c2,c3)), p=p.b, correct = FALSE)
+      H0 <- "1:2:1"
     }
-    else if (grepl("D",x$segr.type[marker])) {
-          if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
-          if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
-          qui <- chisq.test(as.vector(c(c1,c2)), p=p.d, correct = FALSE)
-          H0 <- "1:1"
+    else if (grepl("C",x$segr.type[marker]) & class(x)[2]=="outcross") {
+      if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
+      if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
+      qui <- chisq.test(as.vector(c(c1,c2)), p=p.c, correct = FALSE)
+      H0 <- "3:1"
+    }
+    else if (grepl("D",x$segr.type[marker]) & class(x)[2]=="outcross") {
+      if (is.element(1,x$geno[,marker])) c1 <- count[names(count)==1] else c1 <- 0
+      if (is.element(2,x$geno[,marker])) c2 <- count[names(count)==2] else c2 <- 0
+      qui <- chisq.test(as.vector(c(c1,c2)), p=p.d, correct = FALSE)
+      H0 <- "1:1"
     }
     #impossible to test: dominant and co-dominant mixed in the same marker
     #however, it will not work with "qui <- NA"; using NULL instead
     else if (grepl("M.X",x$segr.type[marker])) {
-        qui <- NULL
-        qui$statistic <- NA
-        qui$p.value <- NA
-        H0 <- "Check data!"
+      qui <- NULL
+      qui$statistic <- NA
+      qui$p.value <- NA
+      H0 <- "Check data!"
     }
-
+    
     return(list(Hypothesis=H0, qui.quad=qui$statistic, p.val=qui$p.value,
                 perc.genot=100*(sum(table(x$geno[,marker], exclude=0))/x$n.ind)))
+  }
 }
 ##'
 
@@ -134,8 +149,8 @@ test_segregation_of_a_marker <- function(x, marker) {
 ##' it.
 ##'
 ##' @examples
-##' data(example_out) # Loads a fake outcross dataset installed with onemap
-##' Chi <- test_segregation(example_out) # Performs the chi-square test for all markers
+##' data(onemap_example_out) # Loads a fake outcross dataset installed with onemap
+##' Chi <- test_segregation(onemap_example_out) # Performs the chi-square test for all markers
 ##' print(Chi) # Shows the results
 ##'
 ##' @export
@@ -166,8 +181,8 @@ test_segregation <- function(x) {
 ##' p-values, and % of individuals genotyped.
 ##'
 ##' @examples
-##' data(example_out) # Loads a fake outcross dataset installed with onemap
-##' Chi <- test_segregation(example_out) # Performs the chi-square test for all markers
+##' data(onemap_example_out) # Loads a fake outcross dataset installed with onemap
+##' Chi <- test_segregation(onemap_example_out) # Performs the chi-square test for all markers
 ##' print(Chi) # Shows the results
 ##'
 ##' @method print onemap_segreg_test
@@ -203,8 +218,8 @@ print.onemap_segreg_test <- function(x,...) {
 ##'
 ##' @examples
 ##'
-##' data(mapmaker_example_bc) # load OneMap's fake dataset for a backcross population
-##' BC.seg <- test_segregation(mapmaker_example_bc) # Applies chi-square tests
+##' data(onemap_example_bc) # load OneMap's fake dataset for a backcross population
+##' BC.seg <- test_segregation(onemap_example_bc) # Applies chi-square tests
 ##' print(BC.seg) # Shows the results
 ##' plot(BC.seg) # Plot the graph, ordering the p-values
 ##' plot(BC.seg, order=FALSE) # Plot the graph showing the results keeping the order in the dataset
@@ -213,17 +228,16 @@ print.onemap_segreg_test <- function(x,...) {
 ##' # g <- plot(BC.seg)
 ##' # ggplot2::ggsave("SegregationTests.jpg", g, width=7, height=5, dpi=600)
 ##'
-##' data(example_out) # load OneMap's fake dataset for an outcrossing population
-##' Out.seg <- test_segregation(example_out) # Applies chi-square tests
+##' data(onemap_example_out) # load OneMap's fake dataset for an outcrossing population
+##' Out.seg <- test_segregation(onemap_example_out) # Applies chi-square tests
 ##' print(Out.seg) # Shows the results
 ##' plot(Out.seg) # Plot the graph, ordering the p-values
 ##' plot(Out.seg, order=FALSE) # Plot the graph showing the results keeping the order in the dataset
 ##' # You can store the graphic in an object, then save it.
 ##' # For details, see the help of ggplot2's function ggsave()
 ##' g <- plot(Out.seg)
-##' ggplot2::ggsave("SegregationTests.jpg", g, width=7, height=5, dpi=600)
-##'
-##'
+##' # ggplot2::ggsave("SegregationTests.jpg", g, width=7, height=5, dpi=600)
+##' @method plot onemap_segreg_test
 ##' @export
 plot.onemap_segreg_test <- function(x, order=TRUE,...) {
                                         # Create a data frame
@@ -257,14 +271,16 @@ plot.onemap_segreg_test <- function(x, order=TRUE,...) {
 ##' It shows the alpha value to be used in each chi-square segregation test, in order to achieve
 ##' a given global type I error. To do so, it uses Bonferroni's criteria.
 ##'
+##'@importFrom methods is
+##'
 ##' @param x an object of class onemap_segreg_test
 ##' @param global.alpha the global alpha that
 ##'
 ##' @return the alpha value for each test (numeric)
 ##'
 ##' @examples
-##' data(mapmaker_example_bc) # Loads a fake backcross dataset installed with onemap
-##' Chi <- test_segregation(mapmaker_example_bc) # Performs the chi-square test for all markers
+##' data(onemap_example_bc) # Loads a fake backcross dataset installed with onemap
+##' Chi <- test_segregation(onemap_example_bc) # Performs the chi-square test for all markers
 ##' print(Chi) # Shows the results of the Chi-square tests
 ##' Bonferroni_alpha (Chi) # Shows the individual alpha level to be used
 ##'
@@ -284,14 +300,15 @@ Bonferroni_alpha <- function(x, global.alpha=0.05) {
 ##' @param x an object of class onemap_segreg_test
 ##' @param distorted a TRUE/FALSE variable to show distorted or non-distorted markers
 ##' @param numbers a TRUE/FALSE variable to show the numbers or the names of the markers
+##' @param threshold a number between 0 and 1 to specify the threshold to be considered in the test. If NULL, it uses the threshold defined by bonferroni correction with alpha = 0.05 
 ##'
 ##' @return a vector with marker names or numbers, according to the option for "distorted" and "numbers"
 ##'
 ##' @examples
 ##' # Loads a fake backcross dataset installed with onemap
-##' data(mapmaker_example_bc)
+##' data(onemap_example_bc)
 ##' # Performs the chi-square test for all markers
-##' Chi <- test_segregation(mapmaker_example_bc)
+##' Chi <- test_segregation(onemap_example_bc)
 ##' # To show non-distorted markers
 ##' select_segreg(Chi)
 ##' # To show markers with segregation distortion
@@ -300,12 +317,14 @@ Bonferroni_alpha <- function(x, global.alpha=0.05) {
 ##' select_segreg(Chi, distorted=TRUE, numbers=TRUE)
 ##'
 ##' @export
-select_segreg <- function(x, distorted=FALSE, numbers=FALSE) {
+select_segreg <- function(x, distorted=FALSE, numbers=FALSE, threshold = NULL) {
     if (!is(x,"onemap_segreg_test")) stop("This is not an object of class onemap_segreg_test")
     Z <- data.frame(Marker=x$Marker,
                     p.value=unlist(x$Results.of.tests[3,]))
-    if (distorted==FALSE) Z <- subset(Z, p.value>=Bonferroni_alpha(x))
-    else Z <- subset(Z, p.value<Bonferroni_alpha(x))
+    if(is.null(threshold)) thr <- Bonferroni_alpha(x)
+    else  thr <- threshold
+    if (distorted==FALSE) Z <- subset(Z, p.value>=thr)
+    else Z <- subset(Z, p.value<thr)
     if (numbers==TRUE) return(which(x$Marker %in% as.vector(Z[,1])))
     else return(as.vector(Z[,1]))
 }
