@@ -50,6 +50,9 @@ using namespace std;
 #define LN3 1.098612288668109
 #define LN4 1.38629436111989
 #define LN_75 -0.28768207245178
+#define rf_TOL_min 1e-5  
+#define rf_TOL_max 1-1e-5 
+
 
 Rcpp::NumericVector rf_A_A(Rcpp::NumericMatrix n,
 			  int n_ind,
@@ -58,6 +61,7 @@ Rcpp::NumericVector rf_A_A(Rcpp::NumericMatrix n,
   NumericVector r(8);
   int n1, n2, n3, n4;
   double l0, l;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   l0=-2.0*M_LN2*(n_ind-mis);  
   n1=n(4,1)+n(3,2)+n(2,3)+n(1,4);   
   n2=n(4,4)+n(3,3)+n(2,2)+n(1,1);
@@ -79,6 +83,7 @@ Rcpp::NumericVector rf_A_B1(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = - (M_LN2 * (n(2,1)+n(1,1) + n(4,1)+n(3,1)+2*n(2,2)+2*n(1,3)) +
 	  2 * M_LN2*(n(4,2)+n(3,3)+n(2,3)+n(1,2)+n(4,3)+n(3,2)));
@@ -118,6 +123,7 @@ Rcpp::NumericVector rf_A_B2(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = - (M_LN2 * (n(2,1)+n(1,1) + n(4,1)+n(3,1)+2*n(2,2)+2*n(1,3)) +
 	  2 * M_LN2*(n(4,2)+n(3,3)+n(2,3)+n(1,2)+n(4,3)+n(3,2)));
@@ -157,6 +163,7 @@ Rcpp::NumericVector rf_A_B3(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0= -2.0*M_LN2*(n_ind-mis);
 
@@ -203,6 +210,7 @@ Rcpp::NumericVector rf_A_C(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, r0, r1, r2, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   //Likelihoods under h0: r=0.5
   l0=-2*M_LN2*n(4,2)-(LN4-LN3)*n(4,1)-2*M_LN2*(n(3,2)+n(2,2))-(LN4-LN3)*(n(3,1)+n(2,1))-2*M_LN2*n(1,2)-(LN4-LN3)*n(1,1);
   //EM algorithm
@@ -251,6 +259,7 @@ Rcpp::NumericVector rf_A_D1(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0,  rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -273,6 +282,7 @@ Rcpp::NumericVector rf_A_D2(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0,  rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -295,6 +305,7 @@ Rcpp::NumericVector rf_B1_B1(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(2.0*n(3,3)+2.0*n(3,2)+n(3,1)+2.0*n(2,3)+2.0*n(2,2)+n(2,1)+2.0*n(1,3)+2.0*n(1,2)+n(1,1));
   /*EM algorithm*/
@@ -327,6 +338,7 @@ Rcpp::NumericVector rf_B1_B2(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(2*n(3,3)+n(2,1)+n(3,1)+2*n(2,2)+n(1,1))-2*M_LN2*(n(3,2)+n(2,3)+n(1,3)+n(1,2));
   /*EM algorithm*/
@@ -359,6 +371,7 @@ Rcpp::NumericVector rf_B1_B3(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(2.0*n(3,3)+n(3,2)+2.0*n(3,1)+2.0*n(2,3)+n(2,2)+2.0*n(2,1)+2.0*n(1,3)+n(1,2)+2.0*n(1,1));
   /*EM algorithm*/
@@ -399,6 +412,7 @@ Rcpp::NumericVector rf_B1_C(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = LN_75*(n(3,1) + n(2,1) + n(1,1)) - 2.0*M_LN2*(n(3,2)+n(2,2)+n(1,2));
   /*EM algorithm*/
@@ -449,6 +463,7 @@ Rcpp::NumericVector rf_B1_D1(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -472,6 +487,7 @@ Rcpp::NumericVector rf_B1_D2(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -495,6 +511,7 @@ Rcpp::NumericVector rf_B2_B2(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(2.0*n(3,3)+2.0*n(3,2)+n(3,1)+2.0*n(2,3)+2.0*n(2,2)+n(2,1)+2.0*n(1,3)+2.0*n(1,2)+n(1,1));
   /*EM algorithm*/
@@ -531,6 +548,7 @@ Rcpp::NumericVector rf_B2_B3(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(2.0*n(3,3)+n(3,2)+2.0*n(3,1)+2.0*n(2,3)+n(2,2)+2.0*n(2,1)+2.0*n(1,3)+n(1,2)+2.0*n(1,1));
   /*EM algorithm*/
@@ -579,6 +597,7 @@ Rcpp::NumericVector rf_B2_C(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   //Likelihoods under h0: r=0.5
   l0 = LN_75*(n(3,1) + n(2,1) + n(1,1)) - 2.0*M_LN2*(n(3,2) + n(2,2) + n(1,2));
   //EM algorithm
@@ -626,6 +645,7 @@ Rcpp::NumericVector rf_B2_D1(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -648,6 +668,7 @@ Rcpp::NumericVector rf_B2_D2(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -670,6 +691,7 @@ Rcpp::NumericVector rf_B3_B3(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   //Likelihoods under h0: r=0.5
   l0 = -M_LN2*(2*n(3,3)+n(3,2)+2*n(3,1)+2*n(2,3)+n(2,2)+2*n(2,1)+2*n(1,3)+n(1,2)+2*n(1,1));
     //EM algorithm
@@ -684,6 +706,10 @@ Rcpp::NumericVector rf_B3_B3(Rcpp::NumericMatrix n,
 	(2.0*(n_ind-mis)*(2*(rold*rold)-2*rold+1));
     }
   r(0)=rnew;
+  
+  if(rnew < rf_TOL_min) rnew=rf_TOL_min; /*to avoid operations with zero*/
+  if(rnew > rf_TOL_max) rnew=rf_TOL_max; /*to avoid operations with Inf*/
+  
   l=n(2,2)*log(2*(rnew*rnew)-2*rnew+1)+(n(2,3)+n(2,1))*log(rnew-(rnew*rnew))+
     (n(3,2)+n(1,2))*log(2*rnew-2*(rnew*rnew))+(2*n(3,1)+2*n(1,3))*log(rnew)+
     (2*n(3,3)+2*n(1,1))*log(1-rnew);
@@ -710,6 +736,7 @@ Rcpp::NumericVector rf_B3_C(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   //Likelihoods under h0: r=0.5
   l0 = LN_75*(n(3,1)+n(2,1)+n(1,1)) - 2*M_LN2*(n(3,2)+n(2,2)+n(1,2));
   //EM algorithm
@@ -759,6 +786,7 @@ Rcpp::NumericVector rf_B3_D1(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -781,6 +809,7 @@ Rcpp::NumericVector rf_B3_D2(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -803,6 +832,7 @@ Rcpp::NumericVector rf_C_C(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   //Likelihoods under h0: r=0.5
   l0 = LN_75*(n(2,1)+n(1,1))-2*M_LN2*(n(2,2)+n(1,2));
   //EM algorithm
@@ -847,6 +877,7 @@ Rcpp::NumericVector rf_C_D1(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -872,6 +903,7 @@ Rcpp::NumericVector rf_C_D2(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -897,6 +929,7 @@ Rcpp::NumericVector rf_D1_D1(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
@@ -920,6 +953,7 @@ Rcpp::NumericVector rf_D2_D2(Rcpp::NumericMatrix n,
 {
   NumericVector r(8);
   double l, l0, rnew, rold;
+  if((n_ind - mis) ==0) warning("Recombination fraction between some markers could not be estimated, because there are excess of missing data. We suggest to filter your data for missing data.\n");
   /*Likelihoods under h0: r=0.5*/
   l0 = -M_LN2*(n_ind-mis);
   /*EM algorithm*/
